@@ -29,7 +29,7 @@ class SpeechMixED(nn.Module):
         if decoder_input_ids is None and labels is None:
             decoder_input_ids = handle_decoder_input_none(self.model.config.decoder, self.device)
         outputs = self.model(input_values=input_values, decoder_input_ids=decoder_input_ids, labels=labels)
-        return_dict = {'logits': outputs['logits']}
+        return_dict = {'logits': torch.argmax(outputs['logits'], -1)}
         if outputs.get('loss', None):
             return_dict['loss'] = outputs['loss']
         return return_dict
@@ -54,7 +54,7 @@ class SpeechMixEED(nn.Module):
             for xcoder in [self.encoder_model.named_parameters, self.decoder_model.named_parameters]:
                 for name, param in xcoder():
                     if param.requires_grad:
-                        if any([k in name for k in ["layer_norm", "attention"]]):
+                        if any([k in name for k in ["layer_norm", "encoder_attn"]]):
                             param.requires_grad = True
                         else:
                             param.requires_grad = False
@@ -72,7 +72,7 @@ class SpeechMixEED(nn.Module):
         projected_embeds = self.enc_to_dec_proj(inputs_embeds)
         outputs = self.decoder_model(inputs_embeds=projected_embeds,
                                      decoder_input_ids=decoder_input_ids, labels=labels)
-        return_dict = {'logits': outputs['logits']}
+        return_dict = {'logits': torch.argmax(outputs['logits'], -1)}
         if outputs.get('loss', None):
             return_dict['loss'] = outputs['loss']
         return return_dict
